@@ -2,6 +2,7 @@
 Validate and convert a configuration value to it's expected type.
 """
 import datetime
+import re
 import time
 from staticconf.errors import ValidationError
 
@@ -79,7 +80,7 @@ def validate_time(value):
     raise ValidationError("Invalid time format: %s" % value)
 
 
-def validate_iterable(iterable_type, value):
+def _validate_iterable(iterable_type, value):
     """Convert the iterable to iterable_type, or raise a Configuration
     exception.
     """
@@ -94,15 +95,31 @@ def validate_iterable(iterable_type, value):
 
 
 def validate_list(value):
-    return validate_iterable(list, value)
+    return _validate_iterable(list, value)
 
 
 def validate_set(value):
-    return validate_iterable(set, value)
+    return _validate_iterable(set, value)
 
 
 def validate_tuple(value):
-    return validate_iterable(tuple, value)
+    return _validate_iterable(tuple, value)
+
+
+def validate_regex(value):
+    try:
+        return re.compile(value)
+    except (re.error, TypeError), e:
+        raise ValidationError("Invalid regex: %s, %s" % (e, value))
+
+
+def build_list_type_validator(item_validator):
+    """Return a function which validates that the value is a list of items
+    which are validated using item_validator.
+    """
+    def validate_list_of_type(value):
+        return [item_validator(item) for item in validate_list(value)]
+    return validate_list_of_type
 
 
 def validate_any(value):
@@ -121,4 +138,9 @@ validators = {
     'string':   validate_string,
     'time':     validate_time,
     'tuple':    validate_tuple,
-}
\ No newline at end of file
+    'regex':    validate_regex,
+}
+
+def get_validators():
+    """Return an iterator of (validator_name, validator) pairs."""
+    return validators.iteritems()
\ No newline at end of file
